changeset 17759:1e74cc7672ef draft

(svn r22543) -Feature: [NewGRF] Support for station variable 0x69.
author terkhen <terkhen@openttd.org>
date Sat, 04 Jun 2011 21:24:23 +0000
parents 0e811605b53c
children a170a74f959c
files src/newgrf_station.cpp
diffstat 1 files changed, 4 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/newgrf_station.cpp
+++ b/src/newgrf_station.cpp
@@ -329,7 +329,7 @@
 			return GetAnimationFrame(tile);
 
 		/* Variables which use the parameter */
 		/* Variables 0x60 to 0x65 are handled separately below */
 		case 0x66: // Animation frame of nearby tile
 			if (parameter != 0) tile = GetNearbyTile(parameter, tile);
 			return st->TileBelongsToRailStation(tile) ? GetAnimationFrame(tile) : UINT_MAX;
@@ -394,8 +394,8 @@
 		case 0xF7: return GB(this->airport.flags, 8, 8);
 	}
 
-	/* Handle cargo variables with parameter, 0x60 to 0x65 */
-	if (variable >= 0x60 && variable <= 0x65) {
+	/* Handle cargo variables with parameter, 0x60 to 0x65 and 0x69 */
+	if ((variable >= 0x60 && variable <= 0x65) || variable == 0x69) {
 		CargoID c = GetCargoTranslation(parameter, object->u.station.statspec->grf_prop.grffile);
 
 		if (c == CT_INVALID) return 0;
@@ -408,6 +408,7 @@
 			case 0x63: return ge->cargo.DaysInTransit();
 			case 0x64: return ge->last_speed | (ge->last_age << 8);
 			case 0x65: return GB(ge->acceptance_pickup, GoodsEntry::GES_ACCEPTANCE, 1) << 3;
+			case 0x69: return GB(ge->acceptance_pickup, GoodsEntry::GES_EVER_ACCEPTED, 4);
 		}
 	}
@@ -329,7 +329,7 @@
 
 		/* Variables which use the parameter */
-		/* Variables 0x60 to 0x65 are handled separately below */
+		/* Variables 0x60 to 0x65 and 0x69 are handled separately below */
 		case 0x66: // Animation frame of nearby tile
 			if (parameter != 0) tile = GetNearbyTile(parameter, tile);